data <- read.csv("data.complete.csv")
attach(data)

######################################
# the same as the without-jiji version

# Variable Names

# year  
# month
# GDP (quarterly)
# UNEMPLOYALL = unemployment rate
# SAMP = the number of respondents

# NEWSCHIN = the number of reports about China
# NEWSKR = the number of reports about Korea
# NEWSNK = the number of reports about North Korea

# CHINASA = the more accurate number of reports about China on Asahi newspaper
# CHINYOMI = the more accurate number of reports about China on Yomiuri newspaper
# CHIMAI = the more accurate number of reports about China on Asahi newspaper

# CHINAE = Export to China 
# CHINAI = Import from China
# RKOREAE = Export to Korea
# RKOREAI = Import from Korea
# NKOREAE = Export to North Korea
# NKOREAI = Import from North Korea

source("functions.r")

# make variables

time <- 1900+year+(month-1)/12
econ <- UNEMPLOYALL
log.sample.size <- log(SAMP)
use.news <- ((time>=(1960+((5-1)/12)))&(time<2011))

china.news <- NEWSCHIN
china.trade.gdp <- (CHINAE*1000 + CHINAI*1000)*100/((GDP*(10^9))/3)
china.gap <- (CHINAE - CHINAI)*100/((GDP*(10^6))/3)

korea.news <- NEWSKR
korea.trade.gdp <- (RKOREAE*1000 + RKOREAI*1000)*100/((GDP*(10^9))/3)
korea.gap <- (RKOREAE - RKOREAI)*100/((GDP*(10^6))/3)

NK.news <- NEWSNK
NK.trade.gdp <- (NKOREAE*1000 + NKOREAI*1000)*100/((GDP*(10^9))/3)
NK.gap <- (NKOREAE - NKOREAI)*100/((GDP*(10^6))/3)

# make figures

source("figures.without.jiji.r")

# measurement error?
cor(na.omit(cbind(NEWSCHIN,CHINASA)))
cor(na.omit(cbind(NEWSCHIN,CHINYOMI)))
cor(na.omit(cbind(NEWSCHIN,CHIMAI)))

#########################################
# different from the without-jiji version

# Variable Names
# CHIL = % of lile China
# CHID = % of dislile China
# KORL = % of lile Korea
# KORD = % of dislile Korea
# NKORL = % of lile North Korea
# NKORD = % of dislile North Korea

# make variables

use.like <- ((time>=(1960+((6-1)/12)))&(time<2011))
use.like[year==71&((month==4)|(month==5)|(month==7))] <- F

use.NK.dislike <- ((time>=(1970+((5-1)/12)))&(time<2011))
use.NK.dislike[year==71&((month==4)|(month==5)|(month==7))] <- F
use.NK.id <- c(1:length(use.NK.dislike))[use.NK.dislike]
use.NK.lag <- use.NK.id - 1
length(use.NK.id)-1

CHIN <- 100-CHIL-CHID
KORN <- 100-KORL-KORD
NKORN <- 100-NKORL-NKORD

logodds.china.like <- logodds(CHIL/100)
logodds.china.dislike <- logodds(CHID/100)
logodds.china.neutral <- logodds(CHIN/100)

logodds.korea.like <- logodds(KORL/100)
logodds.korea.dislike <- logodds(KORD/100)
logodds.korea.neutral <- logodds(KORN/100)

logodds.NK.like <- logodds(NKORL/100)
logodds.NK.dislike <- logodds(NKORD/100)
logodds.NK.neutral <- logodds(NKORN/100)

# make figures

source("figures.with.jiji.r")

# Main Analysis

source("do.ecm.trade.econ.lag.r")
out.trade.econ.all
report(out.trade.econ.NK.dislike)[,c(1,2,5)]
write.csv(out.trade.econ.all,file="result.trade.csv")
write.csv(report(out.trade.econ.NK.dislike)[,c(1,2,5)],file="result.trade.NK.csv")

out.trade.econ.china.dislike$par
out.trade.econ.korea.like$par
out.trade.econ.NK.dislike$par
sum(na.omit(KORL<2))/sum(na.omit(KORL>=0))

# simulation

sd.times <- 2
source("simulation.korea.dislike.r")
logit(y.eq)
mean.korea.news
sd.korea.news
mean.korea.news+sd.korea.news
mean.korea.trade.gdp
mean.korea.gap
mean.econ
exp(mean.sample)
mean.time
y.korea.dislike[2,6]
y.korea.dislike[3,3] - y.korea.dislike[3,1]
y.korea.dislike[3,6] - y.korea.dislike[3,4]
(y.korea.dislike[3,6] - y.korea.dislike[3,4])/(y.korea.dislike[3,3] - y.korea.dislike[3,1])
exp(sd.korea.news*out.trade.econ.korea.dislike$par[13])

# robustness check

# China 1964-2010
source("do.ecm.trade.econ.lag.china.r")
report(out.trade.econ.china.like)[,c(1,2,5)]
report(out.trade.econ.china.dislike)[,c(1,2,5)]
length(use.china.id)-1

# what if the 3 missing months in 1971 included?
source("three.months.r")
out.trade.econ.all
report(out.trade.econ.NK.dislike)[,c(1,2,5)]
length(use.NK.id)-1